@@ -14,39 +14,51 @@ from filebrowser.functions import convert_filename
 
 alnum_name_re = re.compile(FOLDER_REGEX, re.U)
 
-class MakeDirForm(forms.Form):
+# CHOICES
+TRANSPOSE_CHOICES = (
+    ("", u"-----"),
+    ("0", _(u"Flip horizontal")),
+    ("1", _(u"Flip vertical")),
+    ("2", _(u"Rotate 90° CW")),
+    ("4", _(u"Rotate 90° CCW")),
+    ("3", _(u"Rotate 180°")),
+)
+
+
+class CreateDirForm(forms.Form):
     """
-    Form for creating Folder.
+    Form for creating a folder.
     """
     
     def __init__(self, path, *args, **kwargs):
         self.path = path
-        super(MakeDirForm, self).__init__(*args, **kwargs)
+        super(CreateDirForm, self).__init__(*args, **kwargs)
         
-    dir_name = forms.CharField(widget=forms.TextInput(attrs=dict({ 'class': 'vTextField' }, max_length=50, min_length=3)), label=_(u'Name'), help_text=_(u'Only letters, numbers, underscores, spaces and hyphens are allowed.'), required=True)
+    name = forms.CharField(widget=forms.TextInput(attrs=dict({ 'class': 'vTextField' }, max_length=50, min_length=3)), label=_(u'Name'), help_text=_(u'Only letters, numbers, underscores, spaces and hyphens are allowed.'), required=True)
     
     def clean_dir_name(self):
-        if self.cleaned_data['dir_name']:
+        if self.cleaned_data['name']:
             # only letters, numbers, underscores, spaces and hyphens are allowed.
-            if not alnum_name_re.search(self.cleaned_data['dir_name']):
+            if not alnum_name_re.search(self.cleaned_data['name']):
                 raise forms.ValidationError(_(u'Only letters, numbers, underscores, spaces and hyphens are allowed.'))
             # Folder must not already exist.
-            if os.path.isdir(os.path.join(self.path, convert_filename(self.cleaned_data['dir_name']))):
+            if os.path.isdir(os.path.join(self.path, convert_filename(self.cleaned_data['name']))):
                 raise forms.ValidationError(_(u'The Folder already exists.'))
-        return convert_filename(self.cleaned_data['dir_name'])
+        return convert_filename(self.cleaned_data['name'])
 
 
-class RenameForm(forms.Form):
+class ChangeForm(forms.Form):
     """
-    Form for renaming Folder/File.
+    Form for renaming a file/folder.
     """
     
-    def __init__(self, path, file_extension, *args, **kwargs):
-        self.path = path
-        self.file_extension = file_extension
-        super(RenameForm, self).__init__(*args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        self.path = kwargs.pop("path", None)
+        self.fileobject = kwargs.pop("fileobject", None)
+        super(ChangeForm, self).__init__(*args, **kwargs)
     
-    name = forms.CharField(widget=forms.TextInput(attrs=dict({ 'class': 'vTextField' }, min_length=1)), label=_(u'New Name'), help_text=_('Only letters, numbers, underscores, spaces and hyphens are allowed.'), required=True)
+    name = forms.CharField(widget=forms.TextInput(attrs=dict({ 'class': 'vTextField' }, max_length=50, min_length=3)), label=_(u'Name'), help_text=_(u'Only letters, numbers, underscores, spaces and hyphens are allowed.'), required=True)
+    transpose = forms.ChoiceField(choices=TRANSPOSE_CHOICES, label=_(u'Flip/Rotate'), required=False)
     
     def clean_name(self):
         if self.cleaned_data['name']:
@@ -54,9 +66,9 @@ class RenameForm(forms.Form):
             if not alnum_name_re.search(self.cleaned_data['name']):
                 raise forms.ValidationError(_(u'Only letters, numbers, underscores, spaces and hyphens are allowed.'))
             #  folder/file must not already exist.
-            if os.path.isdir(os.path.join(self.path, convert_filename(self.cleaned_data['name']))):
+            if os.path.isdir(os.path.join(self.path, convert_filename(self.cleaned_data['name']))) and os.path.join(self.path, convert_filename(self.cleaned_data['name'])) != self.fileobject.path:
                 raise forms.ValidationError(_(u'The Folder already exists.'))
-            elif os.path.isfile(os.path.join(self.path, convert_filename(self.cleaned_data['name']) + self.file_extension)):
+            elif os.path.isfile(os.path.join(self.path, convert_filename(self.cleaned_data['name'])))  and os.path.join(self.path, convert_filename(self.cleaned_data['name'])) != self.fileobject.path:
                 raise forms.ValidationError(_(u'The File already exists.'))
         return convert_filename(self.cleaned_data['name'])
 
